==> resource_planner-0.3.0.gem: app/assets/javascripts/resource_planner/fullcalendar_timeline/fullcalendar_timeline_utils.js <==
// Extentions on the Date class
Date.prototype.yyyymmdd = function () {
  var mm = this.getMonth() + 1; // getMonth() is zero-based
  var dd = this.getDate();

  return [this.getFullYear(),
  (mm > 9 ? '' : '0') + mm,
  (dd > 9 ? '' : '0') + dd
  ].join('-');
};

Date.prototype.diff = function (otherDate, units) {
  return moment(this).diff(moment(otherDate), units.toLowerCase())
};


// Helper/Utility methods

FullcalendarTimeline.prototype.getFormField = function (selector) {
  return this._formFieldsElement.find(selector);
}

function getElementFromSelector(selector) {
  return $(selector)[0];
}

/**
 * Adds time to a date. Modelled after MySQL DATE_ADD function.
 * Example: dateAdd(new Date(), 30, 'minute')  //returns 30 minutes from now.
 * https://stackoverflow.com/a/1214753/18511
 *
 * @param date  Date to start with
 * @param interval Number of units of the given interval to add.
 * @param units One of: year, quarter, month, week, day, hour, minute, second
 */
function dateAdd(date, interval, units) {
  var ret = new Date(date); // don't change original date
  var checkRollover = function () { if (ret.getDate() != date.getDate()) ret.setDate(0); };
  // Make sure interval is a number
  interval = parseInt(interval, 10);

  switch (units.toLowerCase()) {
    case 'year':
    case 'years':
      ret.setFullYear(ret.getFullYear() + interval); checkRollover(); break;
    case 'quarter':
    case 'quarters':
      ret.setMonth(ret.getMonth() + 3 * interval); checkRollover(); break;
    case 'month':
    case 'months':
      ret.setMonth(ret.getMonth() + interval); checkRollover(); break;
    case 'week':
    case 'weeks':
      ret.setDate(ret.getDate() + 7 * interval); break;
    case 'day':
    case 'days':
      ret.setDate(ret.getDate() + interval); break;
    case 'hour':
    case 'hours':
      ret.setTime(ret.getTime() + interval * 3600000); break;
    case 'minute':
    case 'minutes':
      ret.setTime(ret.getTime() + interval * 60000); break;
    case 'second':
    case 'seconds':
      ret.setTime(ret.getTime() + interval * 1000); break;
    default:
      ret = undefined; break;
  }
  return ret;
}

/**
 *
 * @param {*} d Date to format
 */
function formatDate(d) {
  var date_format_str = d.getFullYear().toString() + "-" + ((d.getMonth() + 1).toString().length == 2 ? (d.getMonth() + 1).toString() : "0" + (d.getMonth() + 1).toString()) + "-" + (d.getDate().toString().length == 2 ? d.getDate().toString() : "0" + d.getDate().toString()) + " " + (d.getHours().toString().length == 2 ? d.getHours().toString() : "0" + d.getHours().toString()) + ":" + ((parseInt(d.getMinutes() / 5) * 5).toString().length == 2 ? (d.getMinutes()).toString() : "0" + (d.getMinutes()).toString()); //+":00";
  return date_format_str;
}

/**
*
* @param {*} yr Year to check
*/
function isLeapYear(yr) {
  return (yr % 400) ? ((yr % 100) ? ((yr % 4) ? false : true) : false) : true;
}

/**
* Check if a date falls between two other dates
* https://stackoverflow.com/questions/16080378/check-if-one-date-is-between-two-dates-javascript
*
* @param from  Range start date
* @param to    Range end date
* @param check Date to check
*/
function dateCheck(from, to, check) {
  var fDate, tDate, cDate;
  fDate = Date.parse(from);
  tDate = Date.parse(to);
  cDate = Date.parse(check);

  if ((cDate <= tDate && cDate >= fDate)) {
    return true;
  }
  return false;
}

==> resource_planner-0.3.1.gem: app/assets/javascripts/resource_planner/fullcalendar_timeline/fullcalendar_timeline_utils.js <==
// Extentions on the Date class
Date.prototype.yyyymmdd = function () {
  var mm = this.getMonth() + 1; // getMonth() is zero-based
  var dd = this.getDate();

  return [this.getFullYear(),
  (mm > 9 ? '' : '0') + mm,
  (dd > 9 ? '' : '0') + dd
  ].join('-');
};

Date.prototype.diff = function (otherDate, units) {
  return moment(this).diff(moment(otherDate), units.toLowerCase())
};


// Helper/Utility methods

FullcalendarTimeline.prototype.getFormField = function (selector) {
  return this._formFieldsElement.find(selector);
}

function getElementFromSelector(selector) {
  return $(selector)[0];
}

/**
 * Adds time to a date. Modelled after MySQL DATE_ADD function.
 * Example: dateAdd(new Date(), 30, 'minute')  //returns 30 minutes from now.
 * https://stackoverflow.com/a/1214753/18511
 *
 * @param date  Date to start with
 * @param interval Number of units of the given interval to add.
 * @param units One of: year, quarter, month, week, day, hour, minute, second
 */
function dateAdd(date, interval, units) {
  var ret = new Date(date); // don't change original date
  var checkRollover = function () { if (ret.getDate() != (new Date(date).getDate())) ret.setDate(0); };
  //var checkRollover = function () { if (ret.getDate() != date.getDate()) ret.setDate(0); };

  // Make sure interval is a number
  //interval = parseInt(interval, 10);

  switch (units.toLowerCase()) {
    case 'year':
    case 'years':
      ret.setFullYear(ret.getFullYear() + interval); checkRollover(); break;
    case 'quarter':
    case 'quarters':
      ret.setMonth(ret.getMonth() + 3 * interval); checkRollover(); break;
    case 'month':
    case 'months':
      ret.setMonth(ret.getMonth() + interval); checkRollover(); break;
    case 'week':
    case 'weeks':
      ret.setDate(ret.getDate() + 7 * interval); break;
    case 'day':
    case 'days':
      var hours = interval * 24;
      ret.setTime(ret.getTime() + hours * 3600000); break;
      //ret.setDate(ret.getDate() + interval); break;
    case 'hour':
    case 'hours':
      ret.setTime(ret.getTime() + interval * 3600000); break;
    case 'minute':
    case 'minutes':
      ret.setTime(ret.getTime() + interval * 60000); break;
    case 'second':
    case 'seconds':
      ret.setTime(ret.getTime() + interval * 1000); break;
    default:
      ret = undefined; break;
  }
  return ret;
}

/**
 *
 * @param {*} d Date to format
 */
function formatDate(d) {
  var date_format_str = d.getFullYear().toString() + "-" + ((d.getMonth() + 1).toString().length == 2 ? (d.getMonth() + 1).toString() : "0" + (d.getMonth() + 1).toString()) + "-" + (d.getDate().toString().length == 2 ? d.getDate().toString() : "0" + d.getDate().toString()) + " " + (d.getHours().toString().length == 2 ? d.getHours().toString() : "0" + d.getHours().toString()) + ":" + ((parseInt(d.getMinutes() / 5) * 5).toString().length == 2 ? (d.getMinutes()).toString() : "0" + (d.getMinutes()).toString()); //+":00";
  return date_format_str;
}

/**
*
* @param {*} yr Year to check
*/
function isLeapYear(yr) {
  return (yr % 400) ? ((yr % 100) ? ((yr % 4) ? false : true) : false) : true;
}

/**
* Check if a date falls between two other dates
* https://stackoverflow.com/questions/16080378/check-if-one-date-is-between-two-dates-javascript
*
* @param from  Range start date
* @param to    Range end date
* @param check Date to check
*/
function dateCheck(from, to, check) {
  var fDate, tDate, cDate;
  fDate = Date.parse(from);
  tDate = Date.parse(to);
  cDate = Date.parse(check);

  if ((cDate <= tDate && cDate >= fDate)) {
    return true;
  }
  return false;
}

function setCookie(cname, cvalue, exdays) {
  var d = new Date();
  d.setTime(d.getTime() + (exdays * 24 * 60 * 60 * 1000));
  var expires = 'expires=' + d.toUTCString();
  document.cookie = cname + '=' + cvalue + ';' + expires + ';path=/';
}

function getCookie(cname) {
  var name = cname + '=';
  var decodedCookie = decodeURIComponent(document.cookie);
  var ca = decodedCookie.split(';');
  for (var i = 0; i < ca.length; i++) {
    var c = ca[i];
    while (c.charAt(0) == ' ') {
      c = c.substring(1);
    }
    if (c.indexOf(name) == 0) {
      return c.substring(name.length, c.length);
    }
  }
  return '';
}

function eraseCookie(name) {
  setCookie(name, '', -1);
}
